@@ -6,11 +6,15 @@ path <- tempdir()
 sourcedir <- system.file("testdata", package = "antaresRead")
 
 # Hack: For some unknown reason, this script is executed at some point of
-# the R CMD CHECK before tests are actually run. The following "if" prevents
-# errors at this step
+# the R CMD CHECK before package is correctly installed and tests actually run. 
+# The following "if" prevents errors at this step
 if (sourcedir != "") {
-  untar(file.path(sourcedir, "antares-test-study.tar.gz"), exdir = path, 
-        extras = "--force-local")
+  if (Sys.info()['sysname'] == "Windows") {
+    untar(file.path(sourcedir, "antares-test-study.tar.gz"), exdir = path, 
+          extras = "--force-local")
+  } else {
+    untar(file.path(sourcedir, "antares-test-study.tar.gz"), exdir = path)
+  }
   
   assign("studyPath", file.path(path, "test_case"), envir = globalenv())
   assign("nweeks", 2, envir = globalenv())
